/*
	图片压缩
*/
Plug.canvas={
	func:'',
    /**
     *  图片压缩
     *
     * @access    public
	 * @param imagePath 图片路径
	 * @param param   width:宽度 height 高度 quality 压缩程度
	 * @param func 回调函数
     * @return    string
     */
	compress:function(imagePath,param,func){
		
		if(typeof(param)!='object')
		{
			func && func({status:false,msg:'配置不能为空'});
			return;
		}
		
		var width=param.width || 0;
		var height=param.height || 0;
		var type=param.type || 'image/jpeg';
		var encoderOptions=param.encoderOptions || 1;
		
		var compress=function(img,w,h){
			var cvs = document.createElement('canvas');
			cvs.width=w;
			cvs.height=h;
			var ctx = cvs.getContext('2d');
			ctx.drawImage(img,0,0,w,h);
			var base64Str = cvs.toDataURL(type,encoderOptions);//获取canvas base64数据
			func && func({status:true,base64Str:base64Str});
		}
		
		//创建图片
		var loadImg=function(base64Str){
			var img = new Image;
			img.src = base64Str;
			img.onload = function(){//必须onload之后再画
				var width=param.width || 0;
				var height=param.height || 0;
				width=Math.min(width,img.width);
				height=Math.min(height,img.height);
				
				if(img.width>img.height)
				{
					if(img.width>=width)
					{
						height=width*img.height/img.width;
						compress(img,width,height);
						return;
					}
				}
				else
				{
					if(img.height>=height)
					{
						width=height*img.width/img.height;
						compress(img,width,height);
						return;
					}
				}
				func && func({status:true,base64Str:base64Str});
			}
		}
		
		if(imagePath.substr(0,4)=='http')
		{
			loadImg(imagePath);
		}
		else
		{
			var ext=imagePath.substr(imagePath.lastIndexOf('.')+1);
			var trans = api.require('trans');
			trans.decodeImgToBase64({
				imgPath: imagePath
			}, function(ret, err){
				if (ret.status)
				{
					ret.base64Str='data:image/'+ext+';base64,'+ret.base64Str;
					loadImg(ret.base64Str);
				}
				else
				{
					api.alert({msg:ret});
				}
			});			
		}
	},
    /**
     *  缩略图
     *
     * @access    public
	 * @param url 图片路径
	 * @param param   width:宽度 height 高度 quality 压缩程度  path 保存路径
	 * @param func 回调函数
     * @return    string
     */
	thumb:function(url,param,func){
		var path=param.path;
		if(!path)
		{
			func && func({status:false,data:'路径不能为空'});
		}
		
		var save=function(base64Str){
			var start=path.lastIndexOf('/')+1;
			var imgPath=path.substr(0,start);
			var imgName=path.substr(start);
			var trans = api.require('trans');
			trans.saveImage({
				base64Str:base64Str.substr(base64Str.indexOf(';base64,')+8),
				imgPath:imgPath,
				imgName:imgName
			}, function(ret, err){
				if (ret.status)
				{
					func && func({status:true,data:{path:path}});
				}
				else
				{
					func && func({status:false,data:err});
				}
			});
		}
		
		var self=this;
		if(url.substr(0,4)=='http')
		{
			api.download({
				url:url,
				savePath:path,
				report: false,
				cache: false,
				allowResume: true
			}, function(ret, err){
				if (ret.state == 1)
				{
					self.compress(ret.savePath,param,function(ret){
						if(ret.status)
						{
							save(ret.base64Str);
						}
						else
						{
							func && func(ret);
						}
					})
					//下载成功
				}
				else if(ret.state == 2)
				{
					func && func({status:false,data:'路径不能为空'});
					Log.system('api.download下载远程图片失败'+url+JSON.stringify(err),6);
				}
			});
		}
		else
		{
			self.compress(url,param,function(ret){
				if(ret.status)
				{
					save(ret.base64Str);
				}
				else
				{
					func && func(ret);
				}
			})
		}
	}
}